@@ -1,16 +1,10 @@
-import os
 import math
-
-
-# Define the path to our custom .ttf font
-free_type_compatible_font = os.path.abspath(
-    os.path.join(
-        os.path.dirname(__file__), 'fonts/xd.ttf'
-    )
-)
-print(free_type_compatible_font)
+from matplotlib import font_manager
 from PIL import ImageDraw, ImageFont 
-font = ImageFont.truetype(font=free_type_compatible_font, size=100)
+
+
+fonts = font_manager.findSystemFonts(fontpaths=None, fontext='ttf')
+font = ImageFont.truetype(font=fonts[0], size=100)
 
 
 class Layer:
